==> nextcloud-21.0.2.tgz: nextcloud/apps/weather_status/l10n/pt_PT.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Endereço desconhecido",
    "No result." : "Sem resultados",
    "Error" : "Erro",
    "Weather status" : "Estado do tempo",
    "Weather status in your dashboard" : "Estado do tempo no painel de controlo",
    "Detect location" : "Detectar localização",
    "Set custom address" : "Definir endereço personalizado",
    "Favorites" : "Favoritos",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Céu limpo pelas {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nebulado pelas {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Dia bonito pelas {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Noite bonita pelas {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parcialmente nublado pelas {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nevoeiro pelas {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Chuva fraca às {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Chuva às {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Chuva forte às {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Aguaceiros às {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Aguaceiros fracos às {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Aguaceiros fortes às {time}",
    "More weather for {adr}" : "Mais meteorologia para {adr}",
    "Loading weather" : "A carregar a meteorologia",
    "Set location for weather" : "Definir localização para a meteorologia",
    "Remove from favorites" : "Remover de favoritos",
    "Add as favorite" : "Adicionar como favorito",
    "You are not logged in." : "Não tem sessão iniciada",
    "There was an error getting the weather status information." : "Ocorreu um erro o estado da informação de meteorologia",
    "No weather information found" : "Não foi encontrada informação de meteorologia",
    "Location not found" : "A localização não foi encontrada",
    "There was an error setting the location address." : "Ocorreu um erro ao definir o endereço da localização"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.4.tgz: nextcloud/apps/weather_status/l10n/pt_PT.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Endereço desconhecido",
    "No result." : "Sem resultados",
    "Error" : "Erro",
    "Weather status" : "Estado do tempo",
    "Weather status in your dashboard" : "Estado do tempo no painel de controlo",
    "Detect location" : "Detectar local",
    "Set custom address" : "Definir endereço personalizado",
    "Favorites" : "Favoritos",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Céu limpo pelas {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nebulado pelas {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Dia de céu limpo pelas {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Noite de céu limpo pelas {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parcialmente nublado pelas {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nevoeiro pelas {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Chuva fraca às {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Chuva às {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Chuva forte às {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Aguaceiros às {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Aguaceiros fracos às {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Aguaceiros fortes às {time}",
    "More weather for {adr}" : "Mais meteorologia para {adr}",
    "Loading weather" : "A carregar a meteorologia",
    "Set location for weather" : "Definir localização para a meteorologia",
    "Remove from favorites" : "Remover dos favoritos",
    "Add as favorite" : "Adicionar como favorito",
    "You are not logged in." : "Não tem a sessão iniciada",
    "There was an error getting the weather status information." : "Ocorreu um erro o estado da informação de meteorologia",
    "No weather information found" : "Não foi encontrada informação de meteorologia",
    "Location not found" : "O local não foi encontrada",
    "There was an error setting the location address." : "Ocorreu um erro ao definir o endereço do local",
    "There was an error setting the location." : "Ocorreu um erro ao definir o local",
    "There was an error saving the mode." : "Ocorreu um erro ao guardar o modo",
    "There was an error using personal address." : "Ocorreu um erro ao usar o endereço pessoal"
},
"nplurals=2; plural=(n != 1);");
